package sun.util.locale.provider;

import java.util.Comparator;
import java.util.TreeMap;
import java.util.Map;
import sun.util.calendar.Era;
import sun.util.calendar.CalendarSystem;
import java.util.Locale;
import java.util.Set;
import java.util.spi.CalendarNameProvider;

public class CalendarNameProviderImpl extends CalendarNameProvider implements AvailableLanguageTags
{
    private final LocaleProviderAdapter.Type type;
    private final Set<String> langtags;
    private static int[] REST_OF_STYLES;
    
    public CalendarNameProviderImpl(LocaleProviderAdapter.Type type, Set<String> langtags) {
        this.type = type;
        this.langtags = langtags;
    }
    
    @Override
    public String getDisplayName(String s, int n, int n2, int n3, Locale locale) {
        return this.getDisplayNameImpl(s, n, n2, n3, locale, false);
    }
    
    public String getJavaTimeDisplayName(String s, int n, int n2, int n3, Locale locale) {
        return this.getDisplayNameImpl(s, n, n2, n3, locale, true);
    }
    
    public String getDisplayNameImpl(String anObject, int n, int n2, int n3, Locale locale, boolean b) {
        String displayName = null;
        String resourceKey = this.getResourceKey(anObject, n, n3, b);
        if (resourceKey != null) {
            LocaleResources localeResources = LocaleProviderAdapter.forType(this.type).getLocaleResources(locale);
            String[] array = b ? localeResources.getJavaTimeNames(resourceKey) : localeResources.getCalendarNames(resourceKey);
            if (array == null && resourceKey.indexOf("standalone.") != -1) {
                String replaceFirst = resourceKey.replaceFirst("standalone.", "");
                array = (b ? localeResources.getJavaTimeNames(replaceFirst) : localeResources.getCalendarNames(replaceFirst));
            }
            if (array != null && array.length > 0) {
                if (n == 7 || n == 1) {
                    --n2;
                }
                if (n2 < 0) {
                    return null;
                }
                if (n2 >= array.length) {
                    if (n == 0 && "japanese".equals(anObject)) {
                        Era[] eras = CalendarSystem.forName("japanese").getEras();
                        if (n2 <= eras.length) {
                            if (this.type == LocaleProviderAdapter.Type.CLDR) {
                                LocaleResources localeResources2 = LocaleProviderAdapter.forJRE().getLocaleResources(locale);
                                String resourceKey2 = getResourceKeyFor(LocaleProviderAdapter.Type.JRE, anObject, n, n3, b);
                                array = (b ? localeResources2.getJavaTimeNames(resourceKey2) : localeResources2.getCalendarNames(resourceKey2));
                            }
                            if (array == null || n2 >= array.length) {
                                Era era = eras[n2 - 1];
                                if (b) {
                                    return (getBaseStyle(n3) == 4) ? era.getAbbreviation() : era.getName();
                                }
                                return ((n3 & 0x2) != 0x0) ? era.getName() : era.getAbbreviation();
                            }
                        }
                        else {
                            return null;
                        }
                    }
                    else {
                        return null;
                    }
                }
                displayName = array[n2];
                if (displayName.length() == 0 && (n3 == 32769 || n3 == 32770 || n3 == 32772)) {
                    displayName = this.getDisplayName(anObject, n, n2, getBaseStyle(n3), locale);
                }
            }
        }
        return displayName;
    }
    
    @Override
    public Map<String, Integer> getDisplayNames(String s, int n, int n2, Locale locale) {
        Map<String, Integer> map;
        if (n2 == 0) {
            map = this.getDisplayNamesImpl(s, n, 1, locale, false);
            int[] rest_OF_STYLES = CalendarNameProviderImpl.REST_OF_STYLES;
            for (int length = rest_OF_STYLES.length, i = 0; i < length; ++i) {
                map.putAll(this.getDisplayNamesImpl(s, n, rest_OF_STYLES[i], locale, false));
            }
        }
        else {
            map = this.getDisplayNamesImpl(s, n, n2, locale, false);
        }
        return map.isEmpty() ? null : map;
    }
    
    public Map<String, Integer> getJavaTimeDisplayNames(String s, int n, int n2, Locale locale) {
        Map<String, Integer> displayNamesImpl = this.getDisplayNamesImpl(s, n, n2, locale, true);
        return displayNamesImpl.isEmpty() ? null : displayNamesImpl;
    }
    
    private Map<String, Integer> getDisplayNamesImpl(String s, int n, int n2, Locale locale, boolean b) {
        String resourceKey = this.getResourceKey(s, n, n2, b);
        TreeMap treeMap = new TreeMap(CalendarNameProviderImpl.LengthBasedComparator.INSTANCE);
        if (resourceKey != null) {
            LocaleResources localeResources = LocaleProviderAdapter.forType(this.type).getLocaleResources(locale);
            String[] array = b ? localeResources.getJavaTimeNames(resourceKey) : localeResources.getCalendarNames(resourceKey);
            if (array == null && resourceKey.indexOf("standalone.") != -1) {
                String replaceFirst = resourceKey.replaceFirst("standalone.", "");
                array = (b ? localeResources.getJavaTimeNames(replaceFirst) : localeResources.getCalendarNames(replaceFirst));
            }
            if (array != null && !this.hasDuplicates(array)) {
                if (n == 1) {
                    if (array.length > 0) {
                        treeMap.put(array[0], Integer.valueOf(1));
                    }
                }
                else {
                    int n3 = n == 7;
                    for (int i = 0; i < array.length; ++i) {
                        String s2 = array[i];
                        if (s2.length() != 0) {
                            treeMap.put(s2, Integer.valueOf(n3 + i));
                        }
                    }
                }
            }
        }
        return treeMap;
    }
    
    private static int getBaseStyle(int n) {
        return n & 0xFFFF7FFF;
    }
    
    @Override
    public Locale[] getAvailableLocales() {
        return LocaleProviderAdapter.toLocaleArray(this.langtags);
    }
    
    @Override
    public boolean isSupportedLocale(Locale stripExtensions) {
        if (Locale.ROOT.equals(stripExtensions)) {
            return true;
        }
        String unicodeLocaleType = null;
        if (stripExtensions.hasExtensions()) {
            unicodeLocaleType = stripExtensions.getUnicodeLocaleType("ca");
            stripExtensions = stripExtensions.stripExtensions();
        }
        if (unicodeLocaleType != null) {
            int n = -1;
            switch (unicodeLocaleType.hashCode()) {
                case -1581060683: {
                    if (unicodeLocaleType.equals("buddhist")) {
                        n = 0;
                        break;
                    }
                    break;
                }
                case -752730191: {
                    if (unicodeLocaleType.equals("japanese")) {
                        n = 1;
                        break;
                    }
                    break;
                }
                case 283776265: {
                    if (unicodeLocaleType.equals("gregory")) {
                        n = 2;
                        break;
                    }
                    break;
                }
                case 2093696456: {
                    if (unicodeLocaleType.equals("islamic")) {
                        n = 3;
                        break;
                    }
                    break;
                }
                case 113094: {
                    if (unicodeLocaleType.equals("roc")) {
                        n = 4;
                        break;
                    }
                    break;
                }
            }
            switch (n) {
                case 0:
                case 1:
                case 2:
                case 3:
                case 4: {
                    break;
                }
                default: {
                    return false;
                }
            }
        }
        return this.langtags.contains(stripExtensions.toLanguageTag()) || (this.type == LocaleProviderAdapter.Type.JRE && this.langtags.contains(stripExtensions.toString().replace('_', '-')));
    }
    
    @Override
    public Set<String> getAvailableLanguageTags() {
        return this.langtags;
    }
    
    private boolean hasDuplicates(String[] array) {
        for (int length = array.length, i = 0; i < length - 1; ++i) {
            String s = array[i];
            if (s != null) {
                int j = i + 1;
                while (j < length) {
                    if (s.equals(array[j])) {
                        return true;
                    }
                    ++j;
                }
            }
        }
        return false;
    }
    
    private String getResourceKey(String s, int n, int n2, boolean b) {
        return getResourceKeyFor(this.type, s, n, n2, b);
    }
    
    private static String getResourceKeyFor(LocaleProviderAdapter.Type type, String str, int n, int n2, boolean b) {
        int baseStyle = getBaseStyle(n2);
        int n3 = n2 != baseStyle;
        if ("gregory".equals(str)) {
            str = null;
        }
        int n4 = baseStyle == 4;
        StringBuilder o = new StringBuilder();
        if (b) {
            o.append("java.time.");
        }
        switch (n) {
            case 0: {
                if (str != null) {
                    o.append(str).append('.');
                }
                if (!(n4 == 0)) {
                    o.append("narrow.");
                }
                else if (type == LocaleProviderAdapter.Type.JRE) {
                    if (b && baseStyle == 2) {
                        o.append("long.");
                    }
                    if (baseStyle == 1) {
                        o.append("short.");
                    }
                }
                else if (baseStyle == 2) {
                    o.append("long.");
                }
                o.append("Eras");
                break;
            }
            case 1: {
                if (n4 == 0) {
                    o.append(str).append(".FirstYear");
                    break;
                }
                break;
            }
            case 2: {
                if ("islamic".equals(str)) {
                    o.append(str).append('.');
                }
                if (!(n3 == 0)) {
                    o.append("standalone.");
                }
                o.append("Month").append(toStyleName(baseStyle));
                break;
            }
            case 7: {
                if (n3 && n4) {
                    o.append("standalone.");
                }
                o.append("Day").append(toStyleName(baseStyle));
                break;
            }
            case 9: {
                if (!(n4 == 0)) {
                    o.append("narrow.");
                }
                o.append("AmPmMarkers");
                break;
            }
        }
        return (o.length() > 0) ? o.toString() : null;
    }
    
    private static String toStyleName(int n) {
        switch (n) {
            case 1: {
                return "Abbreviations";
            }
            case 4: {
                return "Narrows";
            }
            default: {
                return "Names";
            }
        }
    }
    
    static {
        CalendarNameProviderImpl.REST_OF_STYLES = new int[] { 32769, 2, 32770, 4, 32772 };
    }
    
    private static class LengthBasedComparator implements Comparator<String>
    {
        private static final CalendarNameProviderImpl.LengthBasedComparator INSTANCE;
        
        @Override
        public int compare(String s, String anotherString) {
            int n = anotherString.length() - s.length();
            return (n == 0) ? s.compareTo(anotherString) : n;
        }
        
        static {
            INSTANCE = new CalendarNameProviderImpl.LengthBasedComparator();
        }
    }
}
